﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Infragistics.Win.UltraWinDock;

namespace DpiTest
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();
			InitializeWindows();
		}

		private SizeF currentScaleFactor = new SizeF(1f, 1f);

		protected override void ScaleControl(SizeF factor, BoundsSpecified specified)
		{
			base.ScaleControl(factor, specified);

			//Record the running scale factor used
			this.currentScaleFactor = new SizeF(
				this.currentScaleFactor.Width*factor.Width,
				this.currentScaleFactor.Height*factor.Height);

			ScaleWindows(factor);
		}

		private void ScaleWindows(SizeF factor)
		{
			foreach (var dockArea in ultraDockManager1.DockAreas)
			{
				dockArea.Size = new Size((int)(dockArea.Size.Width * factor.Width), (int)(dockArea.Size.Height * factor.Height));
				foreach(var pane in dockArea.Panes)
					pane.Size = new Size((int)(pane.Size.Width * factor.Width), (int)(pane.Size.Height * factor.Height));
			}
		}

		private void InitializeWindows()
		{
			ultraDockManager1.ResetControlPanes();

			//Suspend
			ultraDockManager1.BeginUpdate();
			ultraDockManager1.SuspendLayout();

			// Bottom Pane - Log, Output and Debug
			Infragistics.Win.UltraWinDock.DockAreaPane dapBottom =
				new DockAreaPane(Infragistics.Win.UltraWinDock.DockedLocation.DockedBottom, "BottomPane");
			dapBottom.Size = new Size(this.Size.Width, 150);
			dapBottom.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.TabGroup;
			ultraDockManager1.DockAreas.Add(dapBottom);

			Infragistics.Win.UltraWinDock.DockableControlPane dcpLog = new DockableControlPane("Log", "Log");
			dcpLog.Settings.Appearance.Image = 12;
			dapBottom.Panes.Add(dcpLog);
			Infragistics.Win.UltraWinDock.DockableControlPane dcpDebug = new DockableControlPane("Debug", "Debug");
			dcpDebug.Settings.Appearance.Image = 15;
			dapBottom.Panes.Add(dcpDebug);

			// Left Pane - System Explorer, File Explorer, Favourites, Current Windows
			Infragistics.Win.UltraWinDock.DockAreaPane dapLeft =
				new DockAreaPane(Infragistics.Win.UltraWinDock.DockedLocation.DockedLeft, "LeftPane");
			dapLeft.Size = new Size(200, this.Size.Height);
			dapLeft.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.HorizontalSplit;
			ultraDockManager1.DockAreas.Add(dapLeft);

			Infragistics.Win.UltraWinDock.DockableControlPane dcpSystemExplorer = new DockableControlPane("SystemExplorer", "System Explorer");
			dcpSystemExplorer.Settings.Appearance.Image = 11;
			dapLeft.Panes.Add(dcpSystemExplorer);
			Infragistics.Win.UltraWinDock.DockableControlPane dcpFileExplorer = new DockableControlPane("FileExplorer", "File Explorer");
			dcpFileExplorer.Settings.Appearance.Image = 17;
			dapLeft.Panes.Add(dcpFileExplorer);
			Infragistics.Win.UltraWinDock.DockableControlPane dcpFavourites = new DockableControlPane("Favourites", "Favourites");
			dcpFavourites.Settings.Appearance.Image = 19;
			dapLeft.Panes.Add(dcpFavourites);

			Infragistics.Win.UltraWinDock.DockableControlPane dcpCurrentWindows = new DockableControlPane("CurrentWindows", "Current Windows");
			dcpCurrentWindows.Settings.Appearance.Image = 18;
			dapLeft.Panes.Add(dcpCurrentWindows);

			// Top Left Pane - System Explorer, File Explorer, Favourites
			Infragistics.Win.UltraWinDock.DockableGroupPane dgpTopLeft = new DockableGroupPane("TopLeftPane");
			dgpTopLeft.Size = new Size(200, this.Size.Height*2/3);
			dgpTopLeft.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.TabGroup;
			dapLeft.Panes.Add(dgpTopLeft);
			dcpSystemExplorer.RepositionToGroup(dgpTopLeft);
			dcpFileExplorer.RepositionToGroup(dgpTopLeft);
			dcpFavourites.RepositionToGroup(dgpTopLeft);
			dcpCurrentWindows.RepositionToGroup(dgpTopLeft);

			// Right Pane - Toolbox, Wizards, Properties
			Infragistics.Win.UltraWinDock.DockAreaPane dapRight =
				new DockAreaPane(Infragistics.Win.UltraWinDock.DockedLocation.DockedRight, "RightPane");
			dapRight.Size = new Size(200, this.Size.Height);
			dapRight.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.HorizontalSplit;
			ultraDockManager1.DockAreas.Add(dapRight);

			// Top Right Pane - Toolbox, Wizards
			Infragistics.Win.UltraWinDock.DockableGroupPane dgpTopRight = new DockableGroupPane("TopRightPane");
			dgpTopRight.Size = new Size(200, this.Size.Height*2/3);
			dgpTopRight.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.TabGroup;
			dapRight.Panes.Add(dgpTopRight);

			Infragistics.Win.UltraWinDock.DockableControlPane dcpProperties = new DockableControlPane("Properties", "Properties");
			dcpProperties.Settings.Appearance.Image = 13;
			dapRight.Panes.Add(dcpProperties);

			// Bottom Right Pane - Properties
			Infragistics.Win.UltraWinDock.DockableGroupPane dgpBottomRight = new DockableGroupPane("BottomRightPane");
			dgpBottomRight.Size = new Size(200, this.Size.Height/3);
			dgpBottomRight.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.TabGroup;
			dapRight.Panes.Add(dgpBottomRight);
			dcpProperties.RepositionToGroup(dgpBottomRight);

			//Resume
			ultraDockManager1.ResumeLayout();
			ultraDockManager1.EndUpdate();
		}
	}
}
